/*****************************************************************************
* This rexxhook will check if the anonymous password is a valid e-mail address
* If it is not valid, it will not allow the user to login.
*****************************************************************************/
parse arg socket args;

/*****************************************************************************
* IPSVAR() is now called to retreive some variables from IPS/2
* %(usr.anon) will be equal to "1" if the user that try to login is an
* anonymous user.
* %(password) will contain the password typed by anonymous user.
*****************************************************************************/
parse value IPSVAR( socket, '%(usr.anon) %(password)' ) with anon passanon;

emailnotvalid = '530 E-mail address is not valid, please try again.';

/*****************************************************************************
This section will be executed if the user is an anonymous user
*****************************************************************************/
if ( anon = 1 ) then do
  parse var passanon ident'@'domain;
  parse value reverse( domain ) with toplev'.';
  toplev = reverse( toplev );

  /* check if there is more than 2 characters in the ident */
  if ( length( ident ) <= 2 ) then exit emailnotvalid;

  /* check if domain is entered at all */
  if ( domain = '' ) then do
    /* check if @ is last character */
    if ( lastpos( '@', passanon ) \= length( passanon )) then 
      exit emailnotvalid;
  end
  else do
    /* check if there is a dot in the entered domain */
    if ( pos( '.', domain ) = 0 ) then exit emailnotvalid;
  end;
end; /* do */

/* if the user is not an anononymous user, accept password */
/* if the e-mail address is valid, accept password */
exit 0;
