/*--------------------------------------------------------------------------*\
| This RexxHook is called when IPS/2 receive a "SITE" command
|
| In this script, you can add your "SITE" commands or modify the behaviour
| of already implemented commmands.
\*--------------------------------------------------------------------------*/
parse arg socket cmd1 pars;
parse upper var cmd1 cmd1;

/*--------------------------------------------------------------------------*\
| IPSVAR() is now called to retreive some variables from IPS/2
| For the following line, you could also use:
|   anon = IPSVAR(socket, '%(usr.anon)')
|   admin = IPSVAR(socket, '%(usr.admin)')
| but getting all variables at once is faster and less load on your server
\*--------------------------------------------------------------------------*/
parse value IPSVAR( socket, '%(usr.username) %(usr.anon) %(usr.admin)' ) with username anon admin;

select
  when ( CHKCMD( 'ADMIN', cmd1 ) & admin ) then do
    parse value pars with cmd1 pars;
    parse upper var cmd1 cmd1;

    select
      when CHKCMD( 'EXEC', cmd1 )   then exit ADMIN_EXEC( pars );
      when CHKCMD( 'WHO', cmd1 )    then exit ADMIN_WHO( pars );
    otherwise exit 0;
    end; /* select */
  end; /* do */

  when CHKCMD( 'HELP', cmd1 )     then exit HELP( admin );
/* Uncomment to disable SITE WHO access for guest users
  when CHKCMD( 'WHO',  cmd1 )     then exit WHO( anon );
*/
  otherwise exit 0;
end;

exit 0;

/*--------------------------------------------------------------------------*\
| HELP
|
| Description:
| Parameters:
| Returns:
\*--------------------------------------------------------------------------*/
HELP:
parse arg pars;
if ( pars = 1 ) then return '202 End of SITE help text.&scr\rxOnSite_HELP_ADMIN.txt'
else return '202 End of SITE help text.&scr\rxOnSite_HELP.txt';

/*--------------------------------------------------------------------------*\
| WHO
|
| Description:
| Parameters:
| Returns:
\*--------------------------------------------------------------------------*/
WHO:
parse arg pars;
if ( pars = 1 ) then return '200 Unknown SITE command.'
else return 0;

/*--------------------------------------------------------------------------*\
| ADMIN_EXEC [os2command]
|
| Description:     This command execute a normal OS/2 command, and the send
|                  the results to the user.
| Parameters:      OS/2 command line to execute
| Returns:         IPS response string.
\*--------------------------------------------------------------------------*/
ADMIN_EXEC:
parse arg pars;
tempfile = SysTempFileName( 'siteexec.???' );
'cmd.exe /c' pars '>'tempfile' 2>siteexec.err';
return '202 SITE ADMIN EXEC command completed.&'tempfile'!delete';

/*--------------------------------------------------------------------------*\
| ADMIN_WHO {username}
|
| Description:     Advanced WHO listing for administrators.
| Parameters:      None or a list of usernames.
| Returns:         IPS response string.
\*--------------------------------------------------------------------------*/
ADMIN_WHO:
parse arg pars;

call IPSSAY socket, '200-List of online users follows:';
call IPSSAY socket, '200-';
call IPSSAY socket, '200- Sock  Username         Status         Remotehost';
call IPSSAY socket, '200- ----  --------         ------         ----------';

currentsocket = FIRSTSOCKET( socket );

do while ( currentsocket > 0 )
  username = IPSVAR( currentsocket, '%(usr.username)' );
  if ( pos( username, pars ) > 0 ) | ( pars = '' ) then do
    parse value IPSVAR( currentsocket, '%(status) %(idle) %(remotehost) %(remoteip)' ) with status idle remotehost remoteip;
    select
      when ( status =  0 ) then statustxt = 'Not Logged';
      when ( status = 10 ) then statustxt = 'Idle ('idle's)';
      when ( status = 11 ) then statustxt = 'Retriving';
      when ( status = 12 ) then statustxt = 'Storing';
      when ( status = 13 ) then statustxt = 'Listing';
      otherwise statustxt = 'Unknown';
    end;
    tempsay = left( statustxt, 14 )' 'remotehost' <'remoteip'>';
    tempsay = IPSVAR( currentsocket, '%(fill(sock,-5)) %(fill(usr.username,16))')' 'tempsay;
    call IPSSAY socket, '200- 'tempsay;
    if ( status >= 11 ) & ( status <= 13 ) then
      call IPSSAY socket, '200-    -> 'IPSVAR( currentsocket, '%(curpath)' );
  end;
  currentsocket = IPSVAR( currentsocket, '%(sock.next)' );
end; /* do */

call IPSSAY socket, '200-';
return '200 User list completed.';

/*--------------------------------------------------------------------------*\
| CHKCMD
\*--------------------------------------------------------------------------*/
CHKCMD:
arg c1, c2;
return abbrev( c1, c2, 2 );

/*--------------------------------------------------------------------------*\
| FIRSTSOCKET
\*--------------------------------------------------------------------------*/
FIRSTSOCKET:
parse arg socket;
cursock = socket;
do while ( IPSVAR( cursock, '%(sock.prev)' ) > 0 )
  cursock = IPSVAR( cursock, '%(sock.prev)' );
end; /* do */
return cursock;

